# QHBM Library

This repository is a collection of tools for building and training
Quantum Hamiltonian-Based Models.  These tools depend on
[TensorFlow Quantum](https://www.tensorflow.org/quantum),
and are thus compatible with both real and simulated quantum computers.

This is not an officially supported Google product.
